### Name: Forage
### Title: Forage Effect on Dry Matter Intake
### Aliases: Forage ForCow
### Keywords: datasets

### ** Examples

# Average measurement per cow
data( ForCow )

# trt is ordered factor
ForCow$trt <- ordered( ForCow$trt )

# I do heifer, you do cow
ForCowh <- ForCow[ForCow$hc=="H", ]

# stem-and-leaf plot of raw data
stem( ForCowh$dmi, 5 )
# box-plots by treatment
print( bwplot( dmi ~ trt, ForCowh ),
  main = "Forage Raw Data by trt" )

# analysis of variance for heifer
ForCowh.aov <- aov( dmi ~ trt, ForCowh )
ForCowh.aov
summary( ForCowh.aov )

# linear model for heifer -- same idea
ForCowh.lm <- lm( dmi ~ trt, ForCowh )
ForCowh.lm
summary( ForCowh.lm )           # linear models summary
summary.aov( ForCowh.lm )               # anova-type summary

# ordinary means
tapply( ForCowh$dmi, ForCowh$trt, mean )
# predicted values for all responses
data.frame( trt=ForCowh$trt, mean=predict( ForCowh.aov ) )
# predicted values and their standard errors by trt
ForCowh.mean <- predict( ForCowh.aov, se=TRUE )
ForCowh.mean <- data.frame( trt=ForCowh$trt, mean=ForCowh.mean$fit,
   se=ForCowh.mean$se.fit )
ForCowh.mean[ !duplicated( ForCowh$trt ), ]
# least squares means
lsmean( ForCowh.aov )

# polynomial contrasts
coef( ForCowh.aov ) / sqrt(c(1,10,14,10,70))    # or coef( ForCowh.lm )
# use summary.lm to get standard errors
summary.lm( ForCowh.aov )               # or summary( ForCowh.lm )

# S-Plus plot of anova object
# plot( ForCowh.aov )

# residual plot with symbols
tmpdata = data.frame( x = predict( ForCowh.aov ),
  y = resid( ForCowh.aov ), group=ForCowh$trt )
print( xyplot( y ~ x, tmpdata, groups = group,
  xlab="mean by trt", ylab="residual" ))
# residual plot with jittered symbols
# add horizontal lines for 0 and +/- 1 SD
tmpdata$x = jitter( tmpdata$x )
print( xyplot( y ~ x, tmpdata, groups = group,
  panel = function(...) {
    panel.superpose(...)
    panel.abline( h = 0, lty = 2 )
    panel.abline( h=c(-1,1) * std.dev( ForCowh.aov ), lty=3 )
  },
  xlab="mean by trt", ylab="residual" ))

# Full set of cow measurements (3 periods per cow )
data( Forage )

Forage$code <- factor( Forage$code )
Forage$trt <- ordered( Forage$trt )
Forage$per <- ordered( Forage$per, c("Early","Middle","Late") )
Forage$ldmi <- log10( Forage$dmi )

Forage.fit <- aov( ldmi~hc*trt*per+Error( cow ),
   Forage, qr = TRUE )
summary( Forage.fit )

# projections
Forage.proj <- proj( Forage.fit )
Forage.wpint <- apply( Forage.proj$cow[,
   c("hc","trt","hc:trt") ], 1, sum )
Forage.spint <- apply( Forage.proj$Within[,
   c("per","hc:per","trt:per","hc:trt:per") ], 1, sum )
Forage.mean <- Forage.proj[[1]][1]

# H:23.1 Forage Treatment by Period (Heifer or Cow)

# Separate Analysis by Period

ylabs <- c("dry matter intake (DMI)","","")
xlabs <- c("(a) early period","(b) middle period","(c) late period")
mains = c("","Figure H:23.1","")
yaxis <- seq( 12, 24, 2 )
ylim <- log10( c(11.5,24.5) )
lper = levels( Forage$per )

for ( i in seq( along = lper )) {
   tmpfor <- Forage[Forage$per== lper[i], ]
   fit <- lm( log10( dmi )~trt*hc, tmpfor )
   ci.plot( fit, type="b",
     panel = function(x,y,...) {
       panel.abline( h=Forage.mean, lty=3 )
       panel.superpose(x,y,...)
     },
     xlab=xlabs[i], ylab=ylabs[i], main = mains[i],
     more = ( i != 3 ), split=c(i,1,3,1))
} 
#   axis( 2, log10( yaxis ), yaxis )



